@@ -7,7 +7,7 @@ A script to create or update YellowDog resources.
 from copy import deepcopy
 from dataclasses import dataclass
 from datetime import datetime
-from typing import Dict, List, Optional, Set
+from typing import Dict, List, Optional, Set, Tuple
 
 import yellowdog_client.model as model
 from dateparser import parse as date_parse
@@ -278,7 +278,7 @@ def create_compute_source_template(resource: Dict):
         compute_source = CLIENT.compute_client.add_compute_source_template(
             compute_source_template
         )
-        print_log(f"Created Compute Source Template '{name}'" f" ({compute_source.id})")
+        print_log(f"Created Compute Source Template '{name}' ({compute_source.id})")
     else:
         if not confirmed(f"Update existing Compute Source Template '{name}'?"):
             return
@@ -405,9 +405,7 @@ def create_compute_requirement_template(resource: Dict):
     template = CLIENT.compute_client.update_compute_requirement_template(
         compute_template
     )
-    print_log(
-        f"Updated existing Compute Requirement Template '{name}'" f" ({template.id})"
-    )
+    print_log(f"Updated existing Compute Requirement Template '{name}' ({template.id})")
     if ARGS_PARSER.quiet:
         print(template.id)
 
@@ -446,7 +444,7 @@ def create_keyring(resource: Dict, show_secrets: bool = False):
         print_error(f"Failed to create Keyring '{name}': {e}")
 
 
-def create_keyring_via_api(name: str, description: str) -> (Keyring, str):
+def create_keyring_via_api(name: str, description: str) -> Tuple[Keyring, str]:
     """
     Temporary direct API call to create a Keyring and return the shown-once
     password. The password is not available via the SDK call.
