@@ -115,7 +115,7 @@ def main():
         ARGS_PARSER.details = True
 
     if ARGS_PARSER.details and ARGS_PARSER.strip_ids:
-        print_log("Omitting YellowDog IDs (etc.) from detailed JSON objects")
+        print_log("Stripping YellowDog IDs (etc.) from detailed JSON objects")
 
     if ARGS_PARSER.output_file and ARGS_PARSER.details:
         if exists(ARGS_PARSER.output_file):
@@ -959,7 +959,8 @@ def list_users():
                 {
                     PROP_GROUPS: [
                         group.name for group in get_user_groups(CLIENT, user.id)
-                    ]
+                    ],
+                    PROP_RESOURCE: user.__class__.__name__,
                 },
             )
             for user in select(CLIENT, users)
