@@ -23,8 +23,6 @@ from yellowdog_client.model import (
     RunSpecification,
     Task,
     TaskData,
-    TaskErrorMatcher,
-    TaskErrorType,
     TaskGroup,
     TaskInput,
     TaskInputSource,
@@ -56,7 +54,6 @@ from yellowdog_cli.utils.printing import (
     print_log,
     print_numbered_strings,
     print_warning,
-    print_yd_object,
 )
 from yellowdog_cli.utils.property_names import *
 from yellowdog_cli.utils.settings import (
@@ -69,6 +66,7 @@ from yellowdog_cli.utils.settings import (
 )
 from yellowdog_cli.utils.submit_utils import (
     UploadedFiles,
+    generate_dependencies,
     generate_task_error_matchers_list,
     generate_task_input_list,
     generate_taskdata_object,
@@ -479,6 +477,7 @@ def create_task_group(
         if providers_data is None
         else [CloudProvider(provider) for provider in providers_data]
     )
+
     task_timeout_minutes: Optional[float] = check_float_or_int(
         task_group_data.get(TASK_TIMEOUT, config_wr.task_timeout)
     )
@@ -488,6 +487,24 @@ def create_task_group(
         else timedelta(minutes=task_timeout_minutes)
     )
 
+    exclusive_workers = check_bool(
+        task_group_data.get(
+            EXCLUSIVE_WORKERS,
+            wr_data.get(EXCLUSIVE_WORKERS, config_wr.exclusive_workers),
+        )
+    )
+    batch_allocation = check_bool(
+        task_group_data.get(
+            BATCH_ALLOCATION,
+            wr_data.get(BATCH_ALLOCATION, config_wr.batch_allocation),
+        )
+    )
+    if batch_allocation and not exclusive_workers:
+        raise Exception(
+            f"Property '{EXCLUSIVE_WORKERS}' must be set when "
+            f"'{BATCH_ALLOCATION}' is specified"
+        )
+
     run_specification = RunSpecification(
         taskTypes=task_types,
         maximumTaskRetries=check_int(
@@ -500,12 +517,8 @@ def create_task_group(
                 WORKER_TAGS, wr_data.get(WORKER_TAGS, config_wr.worker_tags)
             )
         ),
-        exclusiveWorkers=check_bool(
-            task_group_data.get(
-                EXCLUSIVE_WORKERS,
-                wr_data.get(EXCLUSIVE_WORKERS, config_wr.exclusive_workers),
-            )
-        ),
+        exclusiveWorkers=exclusive_workers,
+        batchAllocation=batch_allocation,
         instanceTypes=check_list(
             task_group_data.get(
                 INSTANCE_TYPES, wr_data.get(INSTANCE_TYPES, config_wr.instance_types)
@@ -544,7 +557,7 @@ def create_task_group(
     task_group = TaskGroup(
         name=task_group_name,
         runSpecification=run_specification,
-        dependentOn=check_str(task_group_data.get(DEPENDENT_ON, None)),
+        dependencies=generate_dependencies(task_group_data),
         finishIfAllTasksFinished=check_bool(
             task_group_data.get(
                 FINISH_IF_ALL_TASKS_FINISHED,
