@@ -59,7 +59,6 @@ for norm, alt in [
 ]:
     if os.getenv(norm) is None and os.getenv(alt) is not None:
         os.environ[norm] = os.getenv(alt)
-        print_log(f"Setting environment variable '{norm}' using value of '{alt}'")
 
 # CLI > YD_CONF > 'config.toml'
 CONFIG_FILE = relpath(
@@ -68,42 +67,50 @@ CONFIG_FILE = relpath(
     else ARGS_PARSER.config_file
 )
 
-try:
-    CONFIG_FILE_DIR = dirname(CONFIG_FILE)
-    config_dir_abs = abspath(CONFIG_FILE_DIR)
-    config_dir_short = Path(config_dir_abs).parts[-1]
-    VARIABLE_SUBSTITUTIONS.update(
-        {"config_dir_abs": config_dir_abs, "config_dir_name": config_dir_short}
-    )
-    print_log(f"Loading configuration data from: '{CONFIG_FILE}'")
-    CONFIG_TOML: Dict = load_toml_file_with_variable_substitutions(CONFIG_FILE)
-    try:
-        validate_properties(CONFIG_TOML, f"'{CONFIG_FILE}'")
-    except Exception as e:
-        print_error(e)
-        exit(1)
-
-except FileNotFoundError as e:
-    if ARGS_PARSER.config_file is not None:
-        print_error(e)
-        exit(1)
-    # No config file, so create a stub config dictionary
-    print_log(
-        "No configuration file; expecting configuration data on command line "
-        "or in environment variables"
-    )
+if ARGS_PARSER.no_config:
+    # Suppress use of any TOML config file
+    print_log(f"Configuration file ('{CONFIG_FILE}') ignored")
     CONFIG_TOML = {COMMON_SECTION: {}}
     CONFIG_FILE_DIR = os.getcwd()
 
-except (PermissionError, TomlDecodeError) as e:
-    print_error(
-        f"Unable to load configuration data from '{CONFIG_FILE}': {e}",
-    )
-    exit(1)
+else:
+    # Attempt to load configuration data from TOML file
+    try:
+        CONFIG_FILE_DIR = dirname(CONFIG_FILE)
+        config_dir_abs = abspath(CONFIG_FILE_DIR)
+        config_dir_short = Path(config_dir_abs).parts[-1]
+        VARIABLE_SUBSTITUTIONS.update(
+            {"config_dir_abs": config_dir_abs, "config_dir_name": config_dir_short}
+        )
+        print_log(f"Loading configuration data from: '{CONFIG_FILE}'")
+        CONFIG_TOML: Dict = load_toml_file_with_variable_substitutions(CONFIG_FILE)
+        try:
+            validate_properties(CONFIG_TOML, f"'{CONFIG_FILE}'")
+        except Exception as e:
+            print_error(e)
+            exit(1)
 
-except Exception as e:
-    print_error(e)
-    exit(1)
+    except FileNotFoundError as e:
+        if ARGS_PARSER.config_file is not None:
+            print_error(e)
+            exit(1)
+        # No config file, so create a stub config dictionary
+        print_log(
+            "No configuration file; expecting configuration data on command line "
+            "or in environment variables"
+        )
+        CONFIG_TOML = {COMMON_SECTION: {}}
+        CONFIG_FILE_DIR = os.getcwd()
+
+    except (PermissionError, TomlDecodeError) as e:
+        print_error(
+            f"Unable to load configuration data from '{CONFIG_FILE}': {e}",
+        )
+        exit(1)
+
+    except Exception as e:
+        print_error(e)
+        exit(1)
 
 
 def load_config_common() -> ConfigCommon:
@@ -123,7 +130,7 @@ def load_config_common() -> ConfigCommon:
 
         # Replace common section properties with command line or
         # environment variable overrides. Precedence is:
-        # command line > environment variable > config file
+        # command line > config file > environment variable
         for key_name, args_parser_value, env_var_name in [
             (KEY, ARGS_PARSER.key, YD_KEY),
             (SECRET, ARGS_PARSER.secret, YD_SECRET),
@@ -137,7 +144,10 @@ def load_config_common() -> ConfigCommon:
                     f"Using '{key_name}' provided on command line "
                     "(or automatically set)"
                 )
-            elif os.environ.get(env_var_name, None) is not None:
+            elif (
+                common_section.get(key_name, None) is None
+                and os.environ.get(env_var_name, None) is not None
+            ):
                 common_section[key_name] = os.environ[env_var_name]
                 print_log(f"Using '{key_name}' provided via the environment")
 
@@ -299,6 +309,7 @@ def load_config_work_requirement() -> ConfigWorkRequirement:
             add_yd_env_vars=wr_section.get(ADD_YD_ENV_VARS, False),
             always_upload=wr_section.get(ALWAYS_UPLOAD, True),
             args=wr_section.get(ARGS, []),
+            batch_allocation=wr_section.get(BATCH_ALLOCATION, None),
             upload_taskoutput=wr_section.get(UPLOAD_TASKOUTPUT, False),
             completed_task_ttl=wr_section.get(COMPLETED_TASK_TTL, None),
             csv_files=csv_files,
